@@ -79,7 +79,7 @@ class TestCli(unittest.TestCase):
         self.assertTrue("\"type\": \"_ssh._tcp\"" in output, output)
         self.assertTrue("\"port\": \"1022\"" in output, output)
         self.assertTrue("\"external_port\": 10000" in output, output)
-        self.assertTrue("\"domain\": \"device.domain.localhost\"" in output, output)
+        self.assertTrue("\"external_host\": \"device.domain.localhost\"" in output, output)
 
     def tearDown(self):
         clean_up()
